Sample Data — CMIS Library v0.4.1 documentation

### Navigation

- index
- modules |
- previous |
- CMIS Library v0.4.1 documentation »

# Sample Data

The /path/to/cmislib/src/data directory contains some sample XML responses from a CMIS service. These are for sample and development purposes and can safely be ignored if you are an end-user of the library.

In some cases there are two files for the same response. For example, ‘types.xml’ came from Alfresco while ‘types.chemistry.xml’ came from the simple Apache Chemistry test server.

### Navigation

- index
- modules |
- previous |
- CMIS Library v0.4.1 documentation »